@@ -23,7 +23,7 @@
 
 class BassEnhancerPreset : public PluginPresetBase {
  public:
-  BassEnhancerPreset(PresetType preset_type, const int& index = 0);
+  explicit BassEnhancerPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
