@@ -23,7 +23,7 @@
 
 class BassLoudnessPreset : public PluginPresetBase {
  public:
-  BassLoudnessPreset(PresetType preset_type, const int& index = 0);
+  explicit BassLoudnessPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
