@@ -23,7 +23,7 @@
 
 class ConvolverPreset : public PluginPresetBase {
  public:
-  ConvolverPreset(PresetType preset_type, const int& index = 0);
+  explicit ConvolverPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
