@@ -23,7 +23,7 @@
 
 class FilterPreset : public PluginPresetBase {
  public:
-  FilterPreset(PresetType preset_type, const int& index = 0);
+  explicit FilterPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
