@@ -19,7 +19,6 @@
 
 #pragma once
 
-#include "lv2_wrapper.hpp"
 #include "plugin_base.hpp"
 
 class Gate : public PluginBase {
@@ -46,7 +45,6 @@ class Gate : public PluginBase {
 
   sigc::signal<void(const float)> attack_zone_start, attack_threshold, release_zone_start, release_threshold, reduction,
       sidechain, curve, envelope;
-  sigc::signal<void(const double)> gating;
 
   float attack_zone_start_port_value = 0.0F;
   float attack_threshold_port_value = 0.0F;
@@ -56,13 +54,10 @@ class Gate : public PluginBase {
   float sidechain_port_value = 0.0F;
   float curve_port_value = 0.0F;
   float envelope_port_value = 0.0F;
-  double gating_port_value = 0.0;
 
  private:
   uint latency_n_frames = 0U;
 
-  std::unique_ptr<lv2::Lv2Wrapper> lv2_wrapper;
-
   std::vector<pw_proxy*> list_proxies;
 
   void update_sidechain_links(const std::string& key);
