@@ -19,7 +19,6 @@
 
 #pragma once
 
-#include "lv2_wrapper.hpp"
 #include "plugin_base.hpp"
 
 class Limiter : public PluginBase {
@@ -54,8 +53,6 @@ class Limiter : public PluginBase {
  private:
   uint latency_n_frames = 0U;
 
-  std::unique_ptr<lv2::Lv2Wrapper> lv2_wrapper;
-
   std::vector<pw_proxy*> list_proxies;
 
   void update_sidechain_links(const std::string& key);
