@@ -23,7 +23,7 @@
 
 class LimiterPreset : public PluginPresetBase {
  public:
-  LimiterPreset(PresetType preset_type, const int& index = 0);
+  explicit LimiterPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
