@@ -20,13 +20,14 @@
 #pragma once
 
 #include "plugin_preset_base.hpp"
+#include "tags_multiband_compressor.hpp"
 
 class MultibandCompressorPreset : public PluginPresetBase {
  public:
-  MultibandCompressorPreset(PresetType preset_type, const int& index = 0);
+  explicit MultibandCompressorPreset(PresetType preset_type, const int& index = 0);
 
  private:
-  static constexpr uint n_bands = 8U;
+  static constexpr uint n_bands = tags::multiband_compressor::n_bands;
 
   void save(nlohmann::json& json) override;
 
