@@ -20,13 +20,14 @@
 #pragma once
 
 #include "plugin_preset_base.hpp"
+#include "tags_multiband_gate.hpp"
 
 class MultibandGatePreset : public PluginPresetBase {
  public:
-  MultibandGatePreset(PresetType preset_type, const int& index = 0);
+  explicit MultibandGatePreset(PresetType preset_type, const int& index = 0);
 
  private:
-  static constexpr uint n_bands = 8U;
+  static constexpr uint n_bands = tags::multiband_gate::n_bands;
 
   void save(nlohmann::json& json) override;
 
