@@ -23,7 +23,7 @@
 
 class PitchPreset : public PluginPresetBase {
  public:
-  PitchPreset(PresetType preset_type, const int& index = 0);
+  explicit PitchPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
