@@ -24,6 +24,7 @@
 #include <mutex>
 #include <ranges>
 #include <span>
+#include "lv2_wrapper.hpp"
 #include "pipe_manager.hpp"
 #include "tags_plugin_name.hpp"
 
@@ -107,6 +108,12 @@ class PluginBase {
 
   void reset_settings();
 
+  void show_native_ui();
+
+  void close_native_ui();
+
+  void set_native_ui_update_frequency(const uint& value);
+
   virtual void setup();
 
   virtual void process(std::span<float>& left_in,
@@ -142,11 +149,13 @@ class PluginBase {
 
   bool post_messages = false;
 
-  uint n_ports = 4;
+  uint n_ports = 4U;
 
   float input_gain = 1.0F;
   float output_gain = 1.0F;
 
+  std::unique_ptr<lv2::Lv2Wrapper> lv2_wrapper;
+
   std::vector<gulong> gconnections;
 
   void setup_input_output_gain();
