@@ -39,8 +39,10 @@
 #include "echo_canceller_preset.hpp"
 #include "equalizer_preset.hpp"
 #include "exciter_preset.hpp"
+#include "expander_preset.hpp"
 #include "filter_preset.hpp"
 #include "gate_preset.hpp"
+#include "level_meter_preset.hpp"
 #include "limiter_preset.hpp"
 #include "loudness_preset.hpp"
 #include "maximizer_preset.hpp"
@@ -133,8 +135,6 @@ class PresetsManager {
 
   std::filesystem::path user_presets_dir, user_input_dir, user_output_dir, autoload_input_dir, autoload_output_dir;
 
-  std::vector<std::filesystem::path> system_input_dir, system_output_dir;
-
   GSettings *settings = nullptr, *soe_settings = nullptr, *sie_settings = nullptr;
 
   GFileMonitor *user_output_monitor = nullptr, *user_input_monitor = nullptr;
