@@ -23,7 +23,7 @@
 
 class SpeexPreset : public PluginPresetBase {
  public:
-  SpeexPreset(PresetType preset_type, const int& index = 0);
+  explicit SpeexPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
