@@ -23,7 +23,7 @@
 
 class StereoToolsPreset : public PluginPresetBase {
  public:
-  StereoToolsPreset(PresetType preset_type, const int& index = 0);
+  explicit StereoToolsPreset(PresetType preset_type, const int& index = 0);
 
  private:
   void save(nlohmann::json& json) override;
