@@ -23,6 +23,10 @@
 
 namespace tags::multiband_compressor {
 
+// mb comp band num const
+
+constexpr unsigned n_bands = 8U;
+
 // gsettings keys tags
 
 constexpr auto band_enable = std::to_array({{"enable-band0"},
@@ -303,4 +307,4 @@ constexpr auto bsa = std::to_array(
 constexpr auto mk =
     std::to_array({{"mk_0"}, {"mk_1"}, {"mk_2"}, {"mk_3"}, {"mk_4"}, {"mk_5"}, {"mk_6"}, std::to_array("mk_7")});
 
-}  // namespace tags::multiband_compressor
\ No newline at end of file
+}  // namespace tags::multiband_compressor
