@@ -77,10 +77,14 @@ inline constexpr auto equalizer_ui = "/com/github/wwmm/easyeffects/ui/equalizer.
 
 inline constexpr auto exciter_ui = "/com/github/wwmm/easyeffects/ui/exciter.ui";
 
+inline constexpr auto expander_ui = "/com/github/wwmm/easyeffects/ui/expander.ui";
+
 inline constexpr auto filter_ui = "/com/github/wwmm/easyeffects/ui/filter.ui";
 
 inline constexpr auto gate_ui = "/com/github/wwmm/easyeffects/ui/gate.ui";
 
+inline constexpr auto level_meter_ui = "/com/github/wwmm/easyeffects/ui/level_meter.ui";
+
 inline constexpr auto limiter_ui = "/com/github/wwmm/easyeffects/ui/limiter.ui";
 
 inline constexpr auto loudness_ui = "/com/github/wwmm/easyeffects/ui/loudness.ui";
