@@ -149,6 +149,16 @@ inline constexpr auto output_path = "/com/github/wwmm/easyeffects/streamoutputs/
 
 }  // namespace tags::schema::exciter
 
+namespace tags::schema::expander {
+
+inline constexpr auto id = "com.github.wwmm.easyeffects.expander";
+
+inline constexpr auto input_path = "/com/github/wwmm/easyeffects/streaminputs/expander/";
+
+inline constexpr auto output_path = "/com/github/wwmm/easyeffects/streamoutputs/expander/";
+
+}  // namespace tags::schema::expander
+
 namespace tags::schema::filter {
 
 inline constexpr auto id = "com.github.wwmm.easyeffects.filter";
@@ -169,6 +179,16 @@ inline constexpr auto output_path = "/com/github/wwmm/easyeffects/streamoutputs/
 
 }  // namespace tags::schema::gate
 
+namespace tags::schema::level_meter {
+
+inline constexpr auto id = "com.github.wwmm.easyeffects.levelmeter";
+
+inline constexpr auto input_path = "/com/github/wwmm/easyeffects/streaminputs/levelmeter/";
+
+inline constexpr auto output_path = "/com/github/wwmm/easyeffects/streamoutputs/levelmeter/";
+
+}  // namespace tags::schema::level_meter
+
 namespace tags::schema::limiter {
 
 inline constexpr auto id = "com.github.wwmm.easyeffects.limiter";
@@ -223,7 +243,7 @@ namespace tags::schema::output_level {
 
 inline constexpr auto id = "com.github.wwmm.easyeffects.outputlevel";
 
-}
+}  // namespace tags::schema::output_level
 
 namespace tags::schema::pitch {
 
@@ -279,4 +299,4 @@ namespace tags::schema::spectrum {
 
 inline constexpr auto id = "com.github.wwmm.easyeffects.spectrum";
 
-}  // namespace tags::schema::spectrum
\ No newline at end of file
+}  // namespace tags::schema::spectrum
