@@ -62,6 +62,8 @@ void save_user_locale();
 
 auto get_user_locale() -> std::locale;
 
+auto get_plugin_credit_translated(const std::string& plugin_package) -> std::string;
+
 void update_level(GtkLevelBar* w_left,
                   GtkLabel* w_left_label,
                   GtkLevelBar* w_right,
@@ -73,10 +75,11 @@ void append_to_string_list(GtkStringList* string_list, const std::string& name);
 
 void remove_from_string_list(GtkStringList* string_list, const std::string& name);
 
-void gsettings_bind_enum_to_dropdown(GSettings* settings,
-                                     const gchar* key,
-                                     GtkDropDown* dropdown,
-                                     GSettingsBindFlags flags = G_SETTINGS_BIND_DEFAULT);
+void init_global_app_settings();
+
+void unref_global_app_settings();
+
+auto get_global_app_settings() -> GSettings*;
 
 template <StringLiteralWrapper sl_wrapper, bool lower_bound = true>
 void prepare_spinbutton(GtkSpinButton* button) {
@@ -171,4 +174,40 @@ void gsettings_bind_widgets(GSettings* settings, Targs... widget) {
   (gsettings_bind_widget(settings, key_wrapper.msg.data(), widget), ...);
 }
 
+template <typename T>
+void gsettings_bind_enum_to_combo_widget(GSettings* settings,
+                                         const gchar* key,
+                                         T widget,
+                                         GSettingsBindFlags flags = G_SETTINGS_BIND_DEFAULT) {
+  static_assert(std::is_same_v<T, GtkDropDown*> || std::is_same_v<T, AdwComboRow*>);
+
+  struct Data {
+    GSettings* settings;
+    const gchar* key;
+  };
+
+  g_settings_bind_with_mapping(
+      settings, key, widget, "selected", flags,
+      +[](GValue* value, GVariant* variant, gpointer user_data) {
+        auto* d = static_cast<Data*>(user_data);
+
+        g_value_set_uint(value, static_cast<guint>(g_settings_get_enum(d->settings, d->key)));
+
+        return 1;
+      },
+      +[](const GValue* value, const GVariantType* expected_type, gpointer user_data) {
+        auto* d = static_cast<Data*>(user_data);
+
+        g_settings_set_enum(d->settings, d->key, static_cast<gint>(g_value_get_uint(value)));
+
+        return g_variant_new_string(g_settings_get_string(d->settings, d->key));
+      },
+      new Data({.settings = settings, .key = key}),
+      +[](gpointer user_data) {
+        auto* d = static_cast<Data*>(user_data);
+
+        delete d;
+      });
+}
+
 }  // namespace ui
