@@ -109,10 +109,12 @@ auto get_files_name(const std::filesystem::path& dir_path, const std::string& ex
 
 void reset_all_keys_except(GSettings* settings,
                            const std::vector<std::string>& blocklist = std::vector<std::string>(),
-                           bool delay = true);
+                           bool delay = false);
 
 auto str_contains(const std::string& haystack, const std::string& needle) -> bool;
 
+auto compare_versions(const std::string& v0, const std::string& v1) -> int;
+
 template <typename T>
 void print_type(T v) {
   warning(typeid(v).name());
