@@ -23,8 +23,9 @@ BassLoudness::BassLoudness(const std::string& tag,
                            const std::string& schema,
                            const std::string& schema_path,
                            PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::bass_loudness, tags::plugin_package::mda, schema, schema_path, pipe_manager),
-      lv2_wrapper(std::make_unique<lv2::Lv2Wrapper>("http://drobilla.net/plugins/mda/Loudness")) {
+    : PluginBase(tag, tags::plugin_name::bass_loudness, tags::plugin_package::mda, schema, schema_path, pipe_manager) {
+  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://drobilla.net/plugins/mda/Loudness");
+
   package_installed = lv2_wrapper->found_plugin;
 
   if (!package_installed) {
