@@ -25,7 +25,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   std::shared_ptr<Compressor> compressor;
 
@@ -41,14 +41,15 @@ struct _CompressorBox {
 
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
-  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
+  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
+      *plugin_credit;
 
   GtkLabel *gain_label, *sidechain_label, *curve_label, *envelope_label;
 
   GtkSpinButton *attack, *release, *release_threshold, *threshold, *knee, *ratio, *makeup, *dry, *wet, *boost_threshold,
       *boost_amount, *preamp, *reactivity, *lookahead, *hpf_freq, *lpf_freq;
 
-  GtkToggleButton* listen;
+  GtkToggleButton *listen, *show_native_ui;
 
   GtkDropDown *compression_mode, *sidechain_type, *sidechain_mode, *sidechain_source, *lpf_mode, *hpf_mode,
       *dropdown_input_devices;
@@ -67,6 +68,14 @@ void on_reset(CompressorBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings);
 }
 
+void on_show_native_window(CompressorBox* self, GtkToggleButton* btn) {
+  if (gtk_toggle_button_get_active(btn) != 0) {
+    self->data->compressor->show_native_ui();
+  } else {
+    self->data->compressor->close_native_ui();
+  }
+}
+
 auto set_dropdown_sensitive(CompressorBox* self, const guint selected_id) -> gboolean {
   // Sensitive on External Device selected
   return (selected_id == 2U) ? 1 : 0;
@@ -268,6 +277,8 @@ void setup(CompressorBox* self,
     }
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->compressor->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
   g_settings_bind(self->settings, "dry", gtk_spin_button_get_adjustment(self->dry), "value", G_SETTINGS_BIND_DEFAULT);
@@ -317,17 +328,20 @@ void setup(CompressorBox* self,
 
   g_settings_bind(self->settings, "sidechain-listen", self->listen, "active", G_SETTINGS_BIND_DEFAULT);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "mode", self->compression_mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "mode", self->compression_mode);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "sidechain-type", self->sidechain_type);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "sidechain-type", self->sidechain_type);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "sidechain-mode", self->sidechain_mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "sidechain-mode", self->sidechain_mode);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "sidechain-source", self->sidechain_source);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "sidechain-source", self->sidechain_source);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "hpf-mode", self->hpf_mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "hpf-mode", self->hpf_mode);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "lpf-mode", self->lpf_mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "lpf-mode", self->lpf_mode);
+
+  g_settings_bind(ui::get_global_app_settings(), "show-native-plugin-ui", self->show_native_ui, "visible",
+                  G_SETTINGS_BIND_DEFAULT);
 }
 
 void dispose(GObject* object) {
@@ -335,6 +349,8 @@ void dispose(GObject* object) {
 
   self->data->compressor->set_post_messages(false);
 
+  self->data->compressor->close_native_ui();
+
   set_ignore_filter_idle_add(self->data->serial, true);
 
   for (auto& c : self->data->connections) {
@@ -384,6 +400,7 @@ void compressor_box_class_init(CompressorBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, output_level_right_label);
+  gtk_widget_class_bind_template_child(widget_class, CompressorBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, gain_label);
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, sidechain_label);
@@ -413,8 +430,10 @@ void compressor_box_class_init(CompressorBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, hpf_mode);
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, listen);
   gtk_widget_class_bind_template_child(widget_class, CompressorBox, dropdown_input_devices);
+  gtk_widget_class_bind_template_child(widget_class, CompressorBox, show_native_ui);
 
   gtk_widget_class_bind_template_callback(widget_class, on_reset);
+  gtk_widget_class_bind_template_callback(widget_class, on_show_native_window);
   gtk_widget_class_bind_template_callback(widget_class, set_dropdown_sensitive);
   gtk_widget_class_bind_template_callback(widget_class, set_boost_threshold_sensitive);
   gtk_widget_class_bind_template_callback(widget_class, set_boost_amount_sensitive);
