@@ -25,7 +25,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   std::shared_ptr<Deesser> deesser;
 
@@ -41,7 +41,8 @@ struct _DeesserBox {
 
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
-  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
+  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
+      *plugin_credit;
 
   GtkLevelBar *compression, *detected;
 
@@ -51,7 +52,7 @@ struct _DeesserBox {
 
   GtkToggleButton* sc_listen;
 
-  GtkComboBoxText *detection, *mode;
+  GtkDropDown *detection, *mode;
 
   GSettings* settings;
 
@@ -132,6 +133,8 @@ void setup(DeesserBox* self, std::shared_ptr<Deesser> deesser, const std::string
     });
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->deesser->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
   g_settings_bind(self->settings, "makeup", gtk_spin_button_get_adjustment(self->makeup), "value",
@@ -162,9 +165,9 @@ void setup(DeesserBox* self, std::shared_ptr<Deesser> deesser, const std::string
 
   g_settings_bind(self->settings, "sc-listen", self->sc_listen, "active", G_SETTINGS_BIND_DEFAULT);
 
-  g_settings_bind(self->settings, "detection", self->detection, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "detection", self->detection);
 
-  g_settings_bind(self->settings, "mode", self->mode, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "mode", self->mode);
 }
 
 void dispose(GObject* object) {
@@ -221,6 +224,7 @@ void deesser_box_class_init(DeesserBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, DeesserBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, DeesserBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, DeesserBox, output_level_right_label);
+  gtk_widget_class_bind_template_child(widget_class, DeesserBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, DeesserBox, compression);
   gtk_widget_class_bind_template_child(widget_class, DeesserBox, compression_label);
