@@ -69,6 +69,18 @@ EffectsBase::EffectsBase(std::string tag, const std::string& schema, PipeManager
                                                  }),
                                                  this));
 
+  gconnections_global.push_back(g_signal_connect(global_settings, "changed::lv2ui-update-frequency",
+                                                 G_CALLBACK(+[](GSettings* settings, char* key, gpointer user_data) {
+                                                   auto* self = static_cast<EffectsBase*>(user_data);
+
+                                                   auto v = g_settings_get_int(settings, key);
+
+                                                   for (auto& plugin : self->plugins | std::views::values) {
+                                                     plugin->set_native_ui_update_frequency(v);
+                                                   }
+                                                 }),
+                                                 this));
+
   auto notification_time_window =
       0.001F * static_cast<float>(g_settings_get_int(global_settings, "meters-update-interval"));
 
@@ -149,6 +161,8 @@ void EffectsBase::create_filters_if_necessary() {
       filter = std::make_shared<EchoCanceller>(log_tag, tags::schema::echo_canceller::id, path, pm);
     } else if (name.starts_with(tags::plugin_name::exciter)) {
       filter = std::make_shared<Exciter>(log_tag, tags::schema::exciter::id, path, pm);
+    } else if (name.starts_with(tags::plugin_name::expander)) {
+      filter = std::make_shared<Expander>(log_tag, tags::schema::expander::id, path, pm);
     } else if (name.starts_with(tags::plugin_name::equalizer)) {
       filter =
           std::make_shared<Equalizer>(log_tag, tags::schema::equalizer::id, path, tags::schema::equalizer::channel_id,
@@ -158,6 +172,8 @@ void EffectsBase::create_filters_if_necessary() {
       filter = std::make_shared<Filter>(log_tag, tags::schema::filter::id, path, pm);
     } else if (name.starts_with(tags::plugin_name::gate)) {
       filter = std::make_shared<Gate>(log_tag, tags::schema::gate::id, path, pm);
+    } else if (name.starts_with(tags::plugin_name::level_meter)) {
+      filter = std::make_shared<LevelMeter>(log_tag, tags::schema::level_meter::id, path, pm);
     } else if (name.starts_with(tags::plugin_name::limiter)) {
       filter = std::make_shared<Limiter>(log_tag, tags::schema::limiter::id, path, pm);
     } else if (name.starts_with(tags::plugin_name::loudness)) {
