@@ -30,8 +30,9 @@ Equalizer::Equalizer(const std::string& tag,
                      PipeManager* pipe_manager)
     : PluginBase(tag, tags::plugin_name::equalizer, tags::plugin_package::lsp, schema, schema_path, pipe_manager),
       settings_left(g_settings_new_with_path(schema_channel.c_str(), schema_channel_left_path.c_str())),
-      settings_right(g_settings_new_with_path(schema_channel.c_str(), schema_channel_right_path.c_str())),
-      lv2_wrapper(std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/para_equalizer_x32_lr")) {
+      settings_right(g_settings_new_with_path(schema_channel.c_str(), schema_channel_right_path.c_str())) {
+  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/para_equalizer_x32_lr");
+
   package_installed = lv2_wrapper->found_plugin;
 
   if (!package_installed) {
@@ -61,13 +62,7 @@ Equalizer::Equalizer(const std::string& tag,
                                             using namespace tags::equalizer;
 
                                             for (uint n = 0U; n < self->max_bands; n++) {
-                                              if (n < nbands) {
-                                                g_settings_set_enum(self->settings_left, band_type[n].data(), 1);
-
-                                                if (split) {
-                                                  g_settings_set_enum(self->settings_right, band_type[n].data(), 1);
-                                                }
-                                              } else {
+                                              if (n >= nbands) {
                                                 // turn off unused bands
                                                 g_settings_set_enum(self->settings_left, band_type[n].data(), 0);
 
@@ -187,6 +182,13 @@ void Equalizer::on_split_channels() {
                                                                              g_settings_get_boolean(settings, key));
                                                     }),
                                                     this));
+
+    gconnections_unified.push_back(g_signal_connect(settings_left, ("changed::"s + band_solo[n].data()).c_str(),
+                                                    G_CALLBACK(+[](GSettings* settings, char* key, Equalizer* self) {
+                                                      g_settings_set_boolean(self->settings_right, key,
+                                                                             g_settings_get_boolean(settings, key));
+                                                    }),
+                                                    this));
   }
 }
 
