@@ -31,15 +31,15 @@ struct Data {
 struct _EqualizerBandBox {
   GtkBox parent_instance;
 
-  GtkDropDown *band_type, *band_mode, *band_slope;
+  AdwComboRow *band_type, *band_mode, *band_slope;
 
   GtkButton *reset_frequency, *reset_quality;
 
-  GtkToggleButton *band_solo, *band_mute;
+  GtkSwitch *band_solo, *band_mute;
 
   GtkScale* band_scale;
 
-  GtkSpinButton *band_frequency, *band_quality;
+  GtkSpinButton *band_frequency, *band_quality, *band_gain;
 
   GtkPopover* popover_menu;
 
@@ -59,6 +59,10 @@ void on_reset_frequency(EqualizerBandBox* self, GtkButton* btn) {
   g_settings_reset(self->settings, tags::equalizer::band_frequency[self->data->index].data());
 }
 
+void on_reset_gain(EqualizerBandBox* self, GtkButton* btn) {
+  g_settings_reset(self->settings, tags::equalizer::band_gain[self->data->index].data());
+}
+
 auto set_band_label(EqualizerBandBox* self, double value) -> const char* {
   if (value < 1000.0) {
     // Show no decimal digits: full integer. No need of locale.
@@ -117,11 +121,11 @@ void bind(EqualizerBandBox* self, int index) {
   g_settings_bind(self->settings, tags::equalizer::band_mute[index].data(), self->band_mute, "active",
                   G_SETTINGS_BIND_DEFAULT);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, tags::equalizer::band_type[index].data(), self->band_type);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, tags::equalizer::band_type[index].data(), self->band_type);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, tags::equalizer::band_mode[index].data(), self->band_mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, tags::equalizer::band_mode[index].data(), self->band_mode);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, tags::equalizer::band_slope[index].data(), self->band_slope);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, tags::equalizer::band_slope[index].data(), self->band_slope);
 }
 
 void dispose(GObject* object) {
@@ -163,10 +167,12 @@ void equalizer_band_box_class_init(EqualizerBandBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, EqualizerBandBox, band_scale);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBandBox, band_frequency);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBandBox, band_quality);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBandBox, band_gain);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBandBox, popover_menu);
 
   gtk_widget_class_bind_template_callback(widget_class, on_reset_quality);
   gtk_widget_class_bind_template_callback(widget_class, on_reset_frequency);
+  gtk_widget_class_bind_template_callback(widget_class, on_reset_gain);
   gtk_widget_class_bind_template_callback(widget_class, set_band_scale_sensitive);
   gtk_widget_class_bind_template_callback(widget_class, set_band_label);
   gtk_widget_class_bind_template_callback(widget_class, set_band_quality_label);
@@ -186,6 +192,7 @@ void equalizer_band_box_init(EqualizerBandBox* self) {
 
   prepare_spinbuttons<"Hz">(self->band_frequency);
   prepare_spinbuttons<"">(self->band_quality);
+  prepare_spinbuttons<"dB">(self->band_gain);
 }
 
 auto create() -> EqualizerBandBox* {
