@@ -47,7 +47,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   app::Application* application{};
 
@@ -67,7 +67,8 @@ struct _EqualizerBox {
 
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
-  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
+  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
+      *plugin_credit;
 
   GtkStack* stack;
 
@@ -77,7 +78,7 @@ struct _EqualizerBox {
 
   GtkDropDown* mode;
 
-  GtkToggleButton* split_channels;
+  GtkToggleButton *split_channels, *show_native_ui;
 
   GSettings *settings, *settings_left, *settings_right;
 
@@ -95,6 +96,14 @@ void on_reset(EqualizerBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings_right);
 }
 
+void on_show_native_window(EqualizerBox* self, GtkToggleButton* btn) {
+  if (gtk_toggle_button_get_active(btn) != 0) {
+    self->data->equalizer->show_native_ui();
+  } else {
+    self->data->equalizer->close_native_ui();
+  }
+}
+
 void on_flat_response(EqualizerBox* self, GtkButton* btn) {
   const auto& max_bands = self->data->equalizer->max_bands;
   for (uint n = 0U; n < max_bands; n++) {
@@ -766,6 +775,8 @@ void setup(EqualizerBox* self,
     });
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->equalizer->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
   g_settings_bind(self->settings, "num-bands", gtk_spin_button_get_adjustment(self->nbands), "value",
@@ -773,7 +784,7 @@ void setup(EqualizerBox* self,
 
   g_settings_bind(self->settings, "split-channels", self->split_channels, "active", G_SETTINGS_BIND_DEFAULT);
 
-  ui::gsettings_bind_enum_to_dropdown(self->settings, "mode", self->mode);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "mode", self->mode);
 
   g_settings_bind(self->settings, "balance", gtk_spin_button_get_adjustment(self->balance), "value",
                   G_SETTINGS_BIND_DEFAULT);
@@ -784,6 +795,9 @@ void setup(EqualizerBox* self,
   g_settings_bind(self->settings, "pitch-right", gtk_spin_button_get_adjustment(self->pitch_right), "value",
                   G_SETTINGS_BIND_DEFAULT);
 
+  g_settings_bind(ui::get_global_app_settings(), "show-native-plugin-ui", self->show_native_ui, "visible",
+                  G_SETTINGS_BIND_DEFAULT);
+
   self->data->gconnections.push_back(g_signal_connect(
       self->settings, "changed::num-bands",
       G_CALLBACK(+[](GSettings* settings, char* key, EqualizerBox* self) { build_all_bands(self); }), self));
@@ -802,6 +816,8 @@ void dispose(GObject* object) {
 
   self->data->equalizer->set_post_messages(false);
 
+  self->data->equalizer->close_native_ui();
+
   set_ignore_filter_idle_add(self->data->serial, true);
 
   for (auto& c : self->data->connections) {
@@ -854,6 +870,7 @@ void equalizer_box_class_init(EqualizerBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, output_level_right_label);
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, stack);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, listview_left);
@@ -867,8 +884,11 @@ void equalizer_box_class_init(EqualizerBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, pitch_left);
   gtk_widget_class_bind_template_child(widget_class, EqualizerBox, pitch_right);
 
+  gtk_widget_class_bind_template_child(widget_class, EqualizerBox, show_native_ui);
+
   gtk_widget_class_bind_template_callback(widget_class, on_reset);
 
+  gtk_widget_class_bind_template_callback(widget_class, on_show_native_window);
   gtk_widget_class_bind_template_callback(widget_class, on_flat_response);
   gtk_widget_class_bind_template_callback(widget_class, on_calculate_frequencies);
   gtk_widget_class_bind_template_callback(widget_class, on_sort_bands);
