@@ -20,8 +20,9 @@
 #include "gate.hpp"
 
 Gate::Gate(const std::string& tag, const std::string& schema, const std::string& schema_path, PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::gate, tags::plugin_package::lsp, schema, schema_path, pipe_manager, true),
-      lv2_wrapper(std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/sc_gate_stereo")) {
+    : PluginBase(tag, tags::plugin_name::gate, tags::plugin_package::lsp, schema, schema_path, pipe_manager, true) {
+  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("http://lsp-plug.in/plugins/lv2/sc_gate_stereo");
+
   package_installed = lv2_wrapper->found_plugin;
 
   if (!package_installed) {
@@ -173,13 +174,6 @@ void Gate::process(std::span<float>& left_in,
       curve_port_value = lv2_wrapper->get_control_port_value("clm");
       envelope_port_value = lv2_wrapper->get_control_port_value("elm");
 
-      // Normalize the current gain reduction amount as a percentage,
-      // where 0% is no gating, and 100% is a fully closed gate.
-      // Double needed for the level bar widget.
-      const double max_reduction_port_value = static_cast<double>(lv2_wrapper->get_control_port_value("gr"));
-      // no reduction defaults to 1.0; aka db_to_linear(0 dB);
-      gating_port_value = util::normalize(reduction_port_value, max_reduction_port_value);
-
       attack_zone_start.emit(attack_zone_start_port_value);
       attack_threshold.emit(attack_threshold_port_value);
       release_zone_start.emit(release_zone_start_port_value);
@@ -188,7 +182,6 @@ void Gate::process(std::span<float>& left_in,
       sidechain.emit(sidechain_port_value);
       curve.emit(curve_port_value);
       envelope.emit(envelope_port_value);
-      gating.emit(gating_port_value);
 
       notify();
     }
