@@ -25,7 +25,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   std::shared_ptr<Gate> gate;
 
@@ -41,16 +41,13 @@ struct _GateBox {
 
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
-  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
+  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
+      *plugin_credit;
 
   GtkLabel *attack_zone_start_label, *attack_threshold_label, *release_zone_start_label, *release_threshold_label;
 
   GtkLabel *gain_label, *sidechain_label, *curve_label, *envelope_label;
 
-  GtkLevelBar* gating;
-
-  GtkLabel* gating_label;
-
   GtkToggleButton* hysteresis;
 
   GtkSpinButton *attack, *release, *curve_threshold, *curve_zone, *hysteresis_threshold, *hysteresis_zone, *dry, *wet,
@@ -58,7 +55,7 @@ struct _GateBox {
 
   GtkComboBoxText *sidechain_input, *sidechain_mode, *sidechain_source, *lpf_mode, *hpf_mode;
 
-  GtkToggleButton* listen;
+  GtkToggleButton *listen, *show_native_ui;
 
   GtkDropDown* dropdown_input_devices;
 
@@ -76,6 +73,14 @@ void on_reset(GateBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings);
 }
 
+void on_show_native_window(GateBox* self, GtkToggleButton* btn) {
+  if (gtk_toggle_button_get_active(btn) != 0) {
+    self->data->gate->show_native_ui();
+  } else {
+    self->data->gate->close_native_ui();
+  }
+}
+
 auto set_dropdown_sensitive(GateBox* self, const char* active_id) -> gboolean {
   if (g_strcmp0(active_id, "External") == 0) {
     return 1;
@@ -223,29 +228,14 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
         return;
       }
 
-      if (!GTK_IS_LABEL(self->gain_label) || !GTK_IS_LABEL(self->gating_label)) {
+      if (!GTK_IS_LABEL(self->gain_label)) {
         return;
       }
 
-      gtk_label_set_text(self->gating_label, fmt::format("{0:.0Lf}", util::linear_to_db(value)).c_str());
       gtk_label_set_text(self->gain_label, fmt::format("{0:.0Lf}", util::linear_to_db(value)).c_str());
     });
   }));
 
-  self->data->connections.push_back(gate->gating.connect([=](const double value) {
-    util::idle_add([=]() {
-      if (get_ignore_filter_idle_add(serial)) {
-        return;
-      }
-
-      if (!GTK_IS_LEVEL_BAR(self->gating)) {
-        return;
-      }
-
-      gtk_level_bar_set_value(self->gating, value);
-    });
-  }));
-
   self->data->connections.push_back(gate->envelope.connect([=](const float value) {
     util::idle_add([=]() {
       if (get_ignore_filter_idle_add(serial)) {
@@ -326,6 +316,8 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
     }
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->gate->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
   g_settings_bind(self->settings, "dry", gtk_spin_button_get_adjustment(self->dry), "value", G_SETTINGS_BIND_DEFAULT);
@@ -384,6 +376,9 @@ void setup(GateBox* self, std::shared_ptr<Gate> gate, const std::string& schema_
   g_settings_bind(self->settings, "hpf-mode", self->hpf_mode, "active-id", G_SETTINGS_BIND_DEFAULT);
 
   g_settings_bind(self->settings, "lpf-mode", self->lpf_mode, "active-id", G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(ui::get_global_app_settings(), "show-native-plugin-ui", self->show_native_ui, "visible",
+                  G_SETTINGS_BIND_DEFAULT);
 }
 
 void dispose(GObject* object) {
@@ -391,6 +386,8 @@ void dispose(GObject* object) {
 
   self->data->gate->set_post_messages(false);
 
+  self->data->gate->close_native_ui();
+
   set_ignore_filter_idle_add(self->data->serial, true);
 
   for (auto& c : self->data->connections) {
@@ -440,8 +437,7 @@ void gate_box_class_init(GateBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, GateBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, GateBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, GateBox, output_level_right_label);
-  gtk_widget_class_bind_template_child(widget_class, GateBox, gating);
-  gtk_widget_class_bind_template_child(widget_class, GateBox, gating_label);
+  gtk_widget_class_bind_template_child(widget_class, GateBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, GateBox, attack_zone_start_label);
   gtk_widget_class_bind_template_child(widget_class, GateBox, attack_threshold_label);
@@ -475,7 +471,10 @@ void gate_box_class_init(GateBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, GateBox, listen);
   gtk_widget_class_bind_template_child(widget_class, GateBox, dropdown_input_devices);
 
+  gtk_widget_class_bind_template_child(widget_class, GateBox, show_native_ui);
+
   gtk_widget_class_bind_template_callback(widget_class, on_reset);
+  gtk_widget_class_bind_template_callback(widget_class, on_show_native_window);
   gtk_widget_class_bind_template_callback(widget_class, set_dropdown_sensitive);
 }
 
