@@ -25,7 +25,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   std::shared_ptr<Loudness> loudness;
 
@@ -41,14 +41,17 @@ struct _LoudnessBox {
 
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
-  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label;
+  GtkLabel *input_level_left_label, *input_level_right_label, *output_level_left_label, *output_level_right_label,
+      *plugin_credit;
 
-  GtkComboBoxText *fft_size, *standard;
+  GtkDropDown *fft_size, *standard;
 
   GtkSwitch* clipping;
 
   GtkSpinButton *volume, *clipping_range;
 
+  GtkToggleButton* show_native_ui;
+
   GSettings* settings;
 
   Data* data;
@@ -61,6 +64,14 @@ void on_reset(LoudnessBox* self, GtkButton* btn) {
   util::reset_all_keys_except(self->settings);
 }
 
+void on_show_native_window(LoudnessBox* self, GtkToggleButton* btn) {
+  if (gtk_toggle_button_get_active(btn) != 0) {
+    self->data->loudness->show_native_ui();
+  } else {
+    self->data->loudness->close_native_ui();
+  }
+}
+
 void setup(LoudnessBox* self, std::shared_ptr<Loudness> loudness, const std::string& schema_path) {
   auto serial = get_new_filter_serial();
 
@@ -98,11 +109,13 @@ void setup(LoudnessBox* self, std::shared_ptr<Loudness> loudness, const std::str
     });
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->loudness->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
-  g_settings_bind(self->settings, "fft", self->fft_size, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "fft", self->fft_size);
 
-  g_settings_bind(self->settings, "std", self->standard, "active-id", G_SETTINGS_BIND_DEFAULT);
+  ui::gsettings_bind_enum_to_combo_widget(self->settings, "std", self->standard);
 
   g_settings_bind(self->settings, "volume", gtk_spin_button_get_adjustment(self->volume), "value",
                   G_SETTINGS_BIND_DEFAULT);
@@ -111,6 +124,9 @@ void setup(LoudnessBox* self, std::shared_ptr<Loudness> loudness, const std::str
 
   g_settings_bind(self->settings, "clipping-range", gtk_spin_button_get_adjustment(self->clipping_range), "value",
                   G_SETTINGS_BIND_DEFAULT);
+
+  g_settings_bind(ui::get_global_app_settings(), "show-native-plugin-ui", self->show_native_ui, "visible",
+                  G_SETTINGS_BIND_DEFAULT);
 }
 
 void dispose(GObject* object) {
@@ -118,6 +134,8 @@ void dispose(GObject* object) {
 
   self->data->loudness->set_post_messages(false);
 
+  self->data->loudness->close_native_ui();
+
   set_ignore_filter_idle_add(self->data->serial, true);
 
   for (auto& c : self->data->connections) {
@@ -167,6 +185,7 @@ void loudness_box_class_init(LoudnessBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, output_level_right_label);
+  gtk_widget_class_bind_template_child(widget_class, LoudnessBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, volume);
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, standard);
@@ -174,7 +193,10 @@ void loudness_box_class_init(LoudnessBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, clipping);
   gtk_widget_class_bind_template_child(widget_class, LoudnessBox, clipping_range);
 
+  gtk_widget_class_bind_template_child(widget_class, LoudnessBox, show_native_ui);
+
   gtk_widget_class_bind_template_callback(widget_class, on_reset);
+  gtk_widget_class_bind_template_callback(widget_class, on_show_native_window);
 }
 
 void loudness_box_init(LoudnessBox* self) {
