@@ -23,8 +23,9 @@ Maximizer::Maximizer(const std::string& tag,
                      const std::string& schema,
                      const std::string& schema_path,
                      PipeManager* pipe_manager)
-    : PluginBase(tag, tags::plugin_name::maximizer, tags::plugin_package::zam, schema, schema_path, pipe_manager),
-      lv2_wrapper(std::make_unique<lv2::Lv2Wrapper>("urn:zamaudio:ZaMaximX2")) {
+    : PluginBase(tag, tags::plugin_name::maximizer, tags::plugin_package::zam, schema, schema_path, pipe_manager) {
+  lv2_wrapper = std::make_unique<lv2::Lv2Wrapper>("urn:zamaudio:ZaMaximX2");
+
   package_installed = lv2_wrapper->found_plugin;
 
   if (!package_installed) {
@@ -38,6 +39,18 @@ Maximizer::Maximizer(const std::string& tag,
   lv2_wrapper->bind_key_double<"rel", "release">(settings);
 
   setup_input_output_gain();
+
+  // g_timeout_add_seconds(1, GSourceFunc(+[](Maximizer* self) {
+  //                         if (!self->lv2_wrapper->has_ui()) {
+  //                           self->lv2_wrapper->load_ui();
+  //                         } else {
+  //                           self->lv2_wrapper->notify_ui();
+  //                           self->lv2_wrapper->update_ui();
+  //                         }
+
+  //                         return 1;
+  //                       }),
+  //                       this);
 }
 
 Maximizer::~Maximizer() {
