@@ -1387,6 +1387,8 @@ void on_core_info(void* data, const struct pw_core_info* info) {
 
   pm->core_name = info->name;
 
+  pm->version = info->version;
+
   spa_dict_get_string(info->props, "default.clock.rate", pm->default_clock_rate);
 
   spa_dict_get_string(info->props, "default.clock.min-quantum", pm->default_min_quantum);
@@ -1479,6 +1481,7 @@ PipeManager::PipeManager() : header_version(pw_get_headers_version()), library_v
   pw_properties_set(props_sink, PW_KEY_NODE_NAME, tags::pipewire::ee_sink_name);
   pw_properties_set(props_sink, PW_KEY_NODE_DESCRIPTION, "Easy Effects Sink");
   pw_properties_set(props_sink, PW_KEY_NODE_VIRTUAL, "true");
+  pw_properties_set(props_sink, PW_KEY_NODE_PASSIVE, "out");
   pw_properties_set(props_sink, "factory.name", "support.null-audio-sink");
   pw_properties_set(props_sink, PW_KEY_MEDIA_CLASS, tags::pipewire::media_class::sink);
   pw_properties_set(props_sink, "audio.position", "FL,FR");
@@ -1659,7 +1662,7 @@ void PipeManager::set_node_mute(pw_proxy* proxy, const bool& state) {
 }
 
 auto PipeManager::count_node_ports(const uint& node_id) -> uint {
-  uint count = 0;
+  uint count = 0U;
 
   for (const auto& port : list_ports) {
     if (port.node_id == node_id) {
