@@ -214,6 +214,7 @@ PluginBase::PluginBase(std::string tag,
   pw_properties_set(props_filter, PW_KEY_MEDIA_TYPE, "Audio");
   pw_properties_set(props_filter, PW_KEY_MEDIA_CATEGORY, "Filter");
   pw_properties_set(props_filter, PW_KEY_MEDIA_ROLE, "DSP");
+  pw_properties_set(props_filter, PW_KEY_NODE_PASSIVE, "true");
 
   filter = pw_filter_new(pm->core, filter_name.c_str(), props_filter);
 
@@ -420,6 +421,33 @@ auto PluginBase::get_latency_seconds() -> float {
   return 0.0F;
 }
 
+void PluginBase::show_native_ui() {
+  if (lv2_wrapper == nullptr) {
+    return;
+  }
+
+  if (!lv2_wrapper->has_ui()) {
+    lv2_wrapper->load_ui();
+  }
+}
+
+void PluginBase::close_native_ui() {
+  if (lv2_wrapper == nullptr) {
+    return;
+  }
+
+  lv2_wrapper->native_ui_to_gsettings();
+  lv2_wrapper->close_ui();
+}
+
+void PluginBase::set_native_ui_update_frequency(const uint& value) {
+  if (lv2_wrapper == nullptr) {
+    return;
+  }
+
+  lv2_wrapper->set_ui_update_rate(value);
+}
+
 void PluginBase::get_peaks(const std::span<float>& left_in,
                            const std::span<float>& right_in,
                            std::span<float>& left_out,
