@@ -18,6 +18,7 @@
  */
 
 #include "presets_menu.hpp"
+#include "config.h"
 
 namespace ui::presets_menu {
 
@@ -105,6 +106,12 @@ void import_preset(PresetsMenu* self) {
   gtk_file_dialog_set_title(dialog, _("Import Preset"));
   gtk_file_dialog_set_accept_label(dialog, _("Open"));
 
+  auto* init_folder = g_file_new_for_path(SYSTEM_PRESETS_DIR);
+
+  gtk_file_dialog_set_initial_folder(dialog, init_folder);
+
+  g_object_unref(init_folder);
+
   GListStore* filters = g_list_store_new(GTK_TYPE_FILE_FILTER);
 
   auto* filter = gtk_file_filter_new();
@@ -120,15 +127,20 @@ void import_preset(PresetsMenu* self) {
 
   g_object_unref(filters);
 
-  gtk_file_dialog_open(
+  gtk_file_dialog_open_multiple(
       dialog, active_window, nullptr,
       +[](GObject* source_object, GAsyncResult* result, gpointer user_data) {
         auto* self = static_cast<PresetsMenu*>(user_data);
         auto* dialog = GTK_FILE_DIALOG(source_object);
 
-        auto* file = gtk_file_dialog_open_finish(dialog, result, nullptr);
+        auto* files_list = gtk_file_dialog_open_multiple_finish(dialog, result, nullptr);
 
-        if (file != nullptr) {
+        if (files_list == nullptr) {
+          return;
+        }
+
+        for (guint n = 0U; n < g_list_model_get_n_items(files_list); n++) {
+          auto* file = static_cast<GFile*>(g_list_model_get_item(files_list, n));
           auto* path = g_file_get_path(file);
 
           if constexpr (preset_type == PresetType::output) {
@@ -138,9 +150,9 @@ void import_preset(PresetsMenu* self) {
           }
 
           g_free(path);
-
-          g_object_unref(file);
         }
+
+        g_object_unref(files_list);
       },
       self);
 }
@@ -168,10 +180,27 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
         auto* save = gtk_builder_get_object(builder, "save");
         auto* remove = gtk_builder_get_object(builder, "remove");
 
+        auto* confirmation_box = gtk_builder_get_object(builder, "confirmation_box");
+        auto* confirmation_label = gtk_builder_get_object(builder, "confirmation_label");
+        auto* confirmation_yes = gtk_builder_get_object(builder, "confirmation_yes");
+        auto* confirmation_no = gtk_builder_get_object(builder, "confirmation_no");
+
         g_object_set_data(G_OBJECT(item), "name", gtk_builder_get_object(builder, "name"));
         g_object_set_data(G_OBJECT(item), "apply", apply);
-        g_object_set_data(G_OBJECT(item), "save", save);
-        g_object_set_data(G_OBJECT(item), "remove", remove);
+        g_object_set_data(G_OBJECT(item), "confirmation_yes", confirmation_yes);
+
+        g_object_set_data(G_OBJECT(save), "confirmation_box", confirmation_box);
+        g_object_set_data(G_OBJECT(save), "confirmation_label", confirmation_label);
+        g_object_set_data(G_OBJECT(save), "confirmation_yes", confirmation_yes);
+
+        g_object_set_data(G_OBJECT(remove), "confirmation_box", confirmation_box);
+        g_object_set_data(G_OBJECT(remove), "confirmation_label", confirmation_label);
+        g_object_set_data(G_OBJECT(remove), "confirmation_yes", confirmation_yes);
+
+        g_object_set_data(G_OBJECT(confirmation_yes), "confirmation_box", confirmation_box);
+        g_object_set_data(G_OBJECT(confirmation_yes), "confirmation_label", confirmation_label);
+
+        g_object_set_data(G_OBJECT(confirmation_no), "confirmation_label", confirmation_label);
 
         gtk_list_item_set_activatable(item, 0);
         gtk_list_item_set_child(item, GTK_WIDGET(top_box));
@@ -201,31 +230,93 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
 
         g_signal_connect(
             save, "clicked", G_CALLBACK(+[](GtkButton* button, PresetsMenu* self) {
-              if (auto* string_object = GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(button), "string-object"));
-                  string_object != nullptr) {
-                auto* preset_name = gtk_string_object_get_string(string_object);
+              auto* confirmation_box = static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_box"));
 
-                if constexpr (preset_type == PresetType::output) {
-                  self->data->application->presets_manager->save_preset_file(PresetType::output, preset_name);
-                } else if constexpr (preset_type == PresetType::input) {
-                  self->data->application->presets_manager->save_preset_file(PresetType::input, preset_name);
-                }
-              }
+              auto* confirmation_label =
+                  static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(button), "confirmation_label"));
+
+              auto* confirmation_yes = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(button), "confirmation_yes"));
+
+              gtk_label_set_text(confirmation_label, _("Save?"));
+
+              gtk_widget_add_css_class(GTK_WIDGET(confirmation_label), "warning");
+
+              gtk_widget_set_visible(GTK_WIDGET(confirmation_box), 1);
+
+              g_object_set_data(G_OBJECT(confirmation_yes), "operation", GUINT_TO_POINTER(0));
             }),
             self);
 
         g_signal_connect(
             remove, "clicked", G_CALLBACK(+[](GtkButton* button, PresetsMenu* self) {
+              auto* confirmation_box = static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_box"));
+
+              auto* confirmation_label =
+                  static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(button), "confirmation_label"));
+
+              auto* confirmation_yes = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(button), "confirmation_yes"));
+
+              gtk_label_set_text(confirmation_label, _("Delete?"));
+
+              gtk_widget_add_css_class(GTK_WIDGET(confirmation_label), "error");
+
+              gtk_widget_set_visible(GTK_WIDGET(confirmation_box), 1);
+
+              g_object_set_data(G_OBJECT(confirmation_yes), "operation", GUINT_TO_POINTER(1));
+            }),
+            self);
+
+        g_signal_connect(confirmation_no, "clicked", G_CALLBACK(+[](GtkButton* button, GtkBox* box) {
+                           gtk_widget_set_visible(GTK_WIDGET(box), 0);
+
+                           auto* confirmation_label =
+                               static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_label"));
+
+                           gtk_widget_remove_css_class(GTK_WIDGET(confirmation_label), "warning");
+                           gtk_widget_remove_css_class(GTK_WIDGET(confirmation_label), "error");
+                         }),
+                         confirmation_box);
+
+        g_signal_connect(
+            confirmation_yes, "clicked", G_CALLBACK(+[](GtkButton* button, PresetsMenu* self) {
               if (auto* string_object = GTK_STRING_OBJECT(g_object_get_data(G_OBJECT(button), "string-object"));
                   string_object != nullptr) {
                 auto* preset_name = gtk_string_object_get_string(string_object);
 
-                if constexpr (preset_type == PresetType::output) {
-                  self->data->application->presets_manager->remove(PresetType::output, preset_name);
-                } else if constexpr (preset_type == PresetType::input) {
-                  self->data->application->presets_manager->remove(PresetType::input, preset_name);
+                uint operation = GPOINTER_TO_UINT(g_object_get_data(G_OBJECT(button), "operation"));
+
+                auto* confirmation_label =
+                    static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_label"));
+
+                switch (operation) {
+                  case 0: {  // save
+                    if constexpr (preset_type == PresetType::output) {
+                      self->data->application->presets_manager->save_preset_file(PresetType::output, preset_name);
+                    } else if constexpr (preset_type == PresetType::input) {
+                      self->data->application->presets_manager->save_preset_file(PresetType::input, preset_name);
+                    }
+
+                    gtk_widget_remove_css_class(GTK_WIDGET(confirmation_label), "warning");
+
+                    break;
+                  }
+                  case 1: {  // delete
+                    if constexpr (preset_type == PresetType::output) {
+                      self->data->application->presets_manager->remove(PresetType::output, preset_name);
+                    } else if constexpr (preset_type == PresetType::input) {
+                      self->data->application->presets_manager->remove(PresetType::input, preset_name);
+                    }
+
+                    gtk_widget_remove_css_class(GTK_WIDGET(confirmation_label), "error");
+
+                    break;
+                  }
                 }
               }
+
+              auto* confirmation_box = static_cast<GtkBox*>(g_object_get_data(G_OBJECT(button), "confirmation_box"));
+
+              gtk_widget_set_visible(GTK_WIDGET(confirmation_box), 0);
             }),
             self);
 
@@ -233,24 +324,22 @@ void setup_listview(PresetsMenu* self, GtkListView* listview, GtkStringList* str
       }),
       self);
 
-  g_signal_connect(factory, "bind",
-                   G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, PresetsMenu* self) {
-                     auto* label = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "name"));
-                     auto* apply = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "apply"));
-                     auto* save = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "save"));
-                     auto* remove = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "remove"));
+  g_signal_connect(
+      factory, "bind", G_CALLBACK(+[](GtkSignalListItemFactory* factory, GtkListItem* item, PresetsMenu* self) {
+        auto* label = static_cast<GtkLabel*>(g_object_get_data(G_OBJECT(item), "name"));
+        auto* apply = static_cast<GtkButton*>(g_object_get_data(G_OBJECT(item), "apply"));
+        auto* confirmation_yes = static_cast<GtkButton*>(g_object_get_data(G_OBJECT(item), "confirmation_yes"));
 
-                     auto* string_object = GTK_STRING_OBJECT(gtk_list_item_get_item(item));
+        auto* string_object = GTK_STRING_OBJECT(gtk_list_item_get_item(item));
 
-                     g_object_set_data(G_OBJECT(apply), "string-object", string_object);
-                     g_object_set_data(G_OBJECT(save), "string-object", string_object);
-                     g_object_set_data(G_OBJECT(remove), "string-object", string_object);
+        g_object_set_data(G_OBJECT(apply), "string-object", string_object);
+        g_object_set_data(G_OBJECT(confirmation_yes), "string-object", string_object);
 
-                     auto* name = gtk_string_object_get_string(string_object);
+        auto* name = gtk_string_object_get_string(string_object);
 
-                     gtk_label_set_text(label, name);
-                   }),
-                   self);
+        gtk_label_set_text(label, name);
+      }),
+      self);
 
   gtk_list_view_set_factory(listview, factory);
 
@@ -304,7 +393,7 @@ void setup(PresetsMenu* self, app::Application* application) {
           return;
         }
 
-        for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->output_string_list)); n++) {
+        for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->output_string_list)); n++) {
           if (preset_name == gtk_string_list_get_string(self->output_string_list, n)) {
             return;
           }
@@ -321,7 +410,7 @@ void setup(PresetsMenu* self, app::Application* application) {
           return;
         }
 
-        for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->output_string_list)); n++) {
+        for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->output_string_list)); n++) {
           if (preset_name == gtk_string_list_get_string(self->output_string_list, n)) {
             gtk_string_list_remove(self->output_string_list, n);
 
@@ -338,7 +427,7 @@ void setup(PresetsMenu* self, app::Application* application) {
           return;
         }
 
-        for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->input_string_list)); n++) {
+        for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->input_string_list)); n++) {
           if (preset_name == gtk_string_list_get_string(self->input_string_list, n)) {
             return;
           }
@@ -355,7 +444,7 @@ void setup(PresetsMenu* self, app::Application* application) {
           return;
         }
 
-        for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->input_string_list)); n++) {
+        for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->input_string_list)); n++) {
           if (preset_name == gtk_string_list_get_string(self->input_string_list, n)) {
             gtk_string_list_remove(self->input_string_list, n);
 
