@@ -18,6 +18,7 @@
  */
 
 #include "rnnoise_ui.hpp"
+#include "config.h"
 
 namespace ui::rnnoise_box {
 
@@ -37,7 +38,7 @@ struct Data {
  public:
   ~Data() { util::debug("data struct destroyed"); }
 
-  uint serial = 0;
+  uint serial = 0U;
 
   app::Application* application;
 
@@ -58,7 +59,7 @@ struct _RNNoiseBox {
   GtkLevelBar *input_level_left, *input_level_right, *output_level_left, *output_level_right;
 
   GtkLabel *active_model_name, *model_active_state, *model_error_state, *input_level_left_label,
-      *input_level_right_label, *output_level_left_label, *output_level_right_label;
+      *input_level_right_label, *output_level_left_label, *output_level_right_label, *plugin_credit;
 
   GtkListView* listview;
 
@@ -133,6 +134,12 @@ void on_import_model_clicked(RNNoiseBox* self, GtkButton* btn) {
   gtk_file_dialog_set_title(dialog, _("Import Model File"));
   gtk_file_dialog_set_accept_label(dialog, _("Open"));
 
+  auto* init_folder = g_file_new_for_path(SYSTEM_RNNOISE_DIR);
+
+  gtk_file_dialog_set_initial_folder(dialog, init_folder);
+
+  g_object_unref(init_folder);
+
   GListStore* filters = g_list_store_new(GTK_TYPE_FILE_FILTER);
 
   auto* filter = gtk_file_filter_new();
@@ -148,22 +155,27 @@ void on_import_model_clicked(RNNoiseBox* self, GtkButton* btn) {
 
   g_object_unref(filters);
 
-  gtk_file_dialog_open(
+  gtk_file_dialog_open_multiple(
       dialog, active_window, nullptr,
       +[](GObject* source_object, GAsyncResult* result, gpointer user_data) {
         auto* dialog = GTK_FILE_DIALOG(source_object);
 
-        auto* file = gtk_file_dialog_open_finish(dialog, result, nullptr);
+        auto* files_list = gtk_file_dialog_open_multiple_finish(dialog, result, nullptr);
 
-        if (file != nullptr) {
+        if (files_list == nullptr) {
+          return;
+        }
+
+        for (guint n = 0U; n < g_list_model_get_n_items(files_list); n++) {
+          auto* file = static_cast<GFile*>(g_list_model_get_item(files_list, n));
           auto* path = g_file_get_path(file);
 
           import_model_file(path);
 
           g_free(path);
-
-          g_object_unref(file);
         }
+
+        g_object_unref(files_list);
       },
       self);
 }
@@ -236,6 +248,8 @@ void setup(RNNoiseBox* self,
     });
   }));
 
+  gtk_label_set_text(self->plugin_credit, ui::get_plugin_credit_translated(self->data->rnnoise->package).c_str());
+
   gsettings_bind_widgets<"input-gain", "output-gain">(self->settings, self->input_gain, self->output_gain);
 
   g_settings_bind_with_mapping(
@@ -253,7 +267,7 @@ void setup(RNNoiseBox* self,
 
         int standard_model_id = 0;
 
-        for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->selection_model)); n++) {
+        for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->selection_model)); n++) {
           auto item = g_list_model_get_item(G_LIST_MODEL(self->selection_model), n);
 
           const std::string model_name = gtk_string_object_get_string(GTK_STRING_OBJECT(item));
@@ -353,6 +367,7 @@ void rnnoise_box_class_init(RNNoiseBoxClass* klass) {
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, input_level_right_label);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, output_level_left_label);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, output_level_right_label);
+  gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, plugin_credit);
 
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, string_list);
   gtk_widget_class_bind_template_child(widget_class, RNNoiseBox, selection_model);
@@ -404,7 +419,7 @@ void rnnoise_box_init(RNNoiseBox* self) {
 
                      switch (event_type) {
                        case G_FILE_MONITOR_EVENT_CREATED: {
-                         for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
+                         for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
                            if (rnn_filename == gtk_string_list_get_string(self->string_list, n)) {
                              return;
                            }
@@ -416,7 +431,7 @@ void rnnoise_box_init(RNNoiseBox* self) {
                        }
 
                        case G_FILE_MONITOR_EVENT_DELETED: {
-                         for (guint n = 0; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
+                         for (guint n = 0U; n < g_list_model_get_n_items(G_LIST_MODEL(self->string_list)); n++) {
                            if (rnn_filename == gtk_string_list_get_string(self->string_list, n)) {
                              gtk_string_list_remove(self->string_list, n);
 
