@@ -40,8 +40,10 @@ auto get_translated() -> std::map<std::string, std::string> {
                                                    {echo_canceller, _("Echo Canceller")},
                                                    {equalizer, _("Equalizer")},
                                                    {exciter, _("Exciter")},
+                                                   {expander, _("Expander")},
                                                    {filter, _("Filter")},
                                                    {gate, _("Gate")},
+                                                   {level_meter, _("Level Meter")},
                                                    {limiter, _("Limiter")},
                                                    {loudness, _("Loudness")},
                                                    {maximizer, _("Maximizer")},
@@ -105,6 +107,10 @@ auto get_base_name(std::string_view name) -> std::string {
     return tags::plugin_name::exciter;
   }
 
+  if (name.starts_with(tags::plugin_name::expander)) {
+    return tags::plugin_name::expander;
+  }
+
   if (name.starts_with(tags::plugin_name::filter)) {
     return tags::plugin_name::filter;
   }
@@ -113,6 +119,10 @@ auto get_base_name(std::string_view name) -> std::string {
     return tags::plugin_name::gate;
   }
 
+  if (name.starts_with(tags::plugin_name::level_meter)) {
+    return tags::plugin_name::level_meter;
+  }
+
   if (name.starts_with(tags::plugin_name::limiter)) {
     return tags::plugin_name::limiter;
   }
@@ -161,15 +171,15 @@ auto get_id(const std::string& name) -> uint {
 
   std::regex_search(name, matches, id_regex);
 
-  if (matches.size() != 2) {
-    return 0;
+  if (matches.size() != 2U) {
+    return 0U;
   }
 
-  if (uint id = 0; util::str_to_num(matches[1], id)) {
+  if (uint id = 0U; util::str_to_num(matches[1], id)) {
     return id;
   }
 
-  return 0;
+  return 0U;
 }
 
 }  // namespace tags::plugin_name
